package com.aucma.production.service.impl;

import com.aucma.common.utils.DateUtils;
import com.aucma.production.domain.AndonEventLog;
import com.aucma.production.mapper.AndonEventLogMapper;
import com.aucma.production.service.IAndonEventLogService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 安灯事件操作日志（审计与追踪）Service业务层处理
 * 
 * @author Yinq
 * @date 2025-10-28
 */
@Service
public class AndonEventLogServiceImpl implements IAndonEventLogService 
{
    @Autowired
    private AndonEventLogMapper andonEventLogMapper;

    /**
     * 查询安灯事件操作日志（审计与追踪）
     * 
     * @param logId 安灯事件操作日志（审计与追踪）主键
     * @return 安灯事件操作日志（审计与追踪）
     */
    @Override
    public AndonEventLog selectAndonEventLogByLogId(Long logId)
    {
        return andonEventLogMapper.selectAndonEventLogByLogId(logId);
    }

    /**
     * 查询安灯事件操作日志（审计与追踪）列表
     * 
     * @param andonEventLog 安灯事件操作日志（审计与追踪）
     * @return 安灯事件操作日志（审计与追踪）
     */
    @Override
    public List<AndonEventLog> selectAndonEventLogList(AndonEventLog andonEventLog)
    {
        return andonEventLogMapper.selectAndonEventLogList(andonEventLog);
    }

    /**
     * 新增安灯事件操作日志（审计与追踪）
     * 
     * @param andonEventLog 安灯事件操作日志（审计与追踪）
     * @return 结果
     */
    @Override
    public int insertAndonEventLog(AndonEventLog andonEventLog)
    {
        andonEventLog.setCreateTime(DateUtils.getNowDate());
        return andonEventLogMapper.insertAndonEventLog(andonEventLog);
    }

    /**
     * 修改安灯事件操作日志（审计与追踪）
     * 
     * @param andonEventLog 安灯事件操作日志（审计与追踪）
     * @return 结果
     */
    @Override
    public int updateAndonEventLog(AndonEventLog andonEventLog)
    {
        andonEventLog.setUpdateTime(DateUtils.getNowDate());
        return andonEventLogMapper.updateAndonEventLog(andonEventLog);
    }

    /**
     * 批量删除安灯事件操作日志（审计与追踪）
     * 
     * @param logIds 需要删除的安灯事件操作日志（审计与追踪）主键
     * @return 结果
     */
    @Override
    public int deleteAndonEventLogByLogIds(Long[] logIds)
    {
        return andonEventLogMapper.deleteAndonEventLogByLogIds(logIds);
    }

    /**
     * 删除安灯事件操作日志（审计与追踪）信息
     * 
     * @param logId 安灯事件操作日志（审计与追踪）主键
     * @return 结果
     */
    @Override
    public int deleteAndonEventLogByLogId(Long logId)
    {
        return andonEventLogMapper.deleteAndonEventLogByLogId(logId);
    }
}
